@@ -3,15 +3,15 @@
 The TestPlatform.Sessions class has a helper method that assists in returning an object given a valid href
 
 """
+from ixnetwork_restpy import SessionAssistant
 
-from ixnetwork_restpy.testplatform.testplatform import TestPlatform
 
-# connect to a test tool platform
-test_platform = TestPlatform('127.0.0.1')
-test_platform.Authenticate('admin', 'admin')
-sessions = test_platform.Sessions.add()
-ixnetwork = sessions.Ixnetwork
-ixnetwork.NewConfig()
+# create a test tool session
+session_assistant = SessionAssistant(IpAddress='127.0.0.1', 
+    UserName='admin', Password='admin', 
+    LogLevel=SessionAssistant.LOGLEVEL_INFO,
+    ClearConfig=True)
+ixnetwork = session_assistant.Ixnetwork
 
 vport = ixnetwork.Vport.add()
 
@@ -20,5 +20,5 @@ vport = ixnetwork.Vport.add()
 # if the vport was connected to an actual hardware port a valid /availableHardware/chassis/card/port object reference 
 # would be returned from the Vport.ConnectedTo property
 # this reference is then used to get an actual object
-hardware_port = sessions.GetObjectFromHref(vport.ConnectedTo)
+hardware_port = session_assistant.Session.GetObjectFromHref(vport.ConnectedTo)
 assert(hardware_port is None)
\ No newline at end of file
