@@ -2,16 +2,14 @@
 by using the Vport.ConnectedTo reference and obtaining the Port object which has the ClearOwnership method
 
 """
-
-from ixnetwork_restpy.testplatform.testplatform import TestPlatform
+from ixnetwork_restpy import SessionAssistant
 
 
-# connect to a test platform, create a session and get the root IxNetwork object
-test_platform = TestPlatform('127.0.0.1')
-test_platform.Authenticate('admin', 'admin')
-sessions = test_platform.Sessions.add()
-ixnetwork = sessions.Ixnetwork
-ixnetwork.NewConfig()
+session_assistant = SessionAssistant(IpAddress='127.0.0.1', 
+    UserName='admin', Password='admin',
+    LogLevel=SessionAssistant.LOGLEVEL_INFO, 
+    ClearConfig=True)
+ixnetwork = session_assistant.Ixnetwork
 
 # add a chassis
 chassis = ixnetwork.AvailableHardware.Chassis.add(Hostname='10.36.74.17')
@@ -23,7 +21,7 @@ for port in card.Port.find():
 
 # clear the ownership on the port using a reference returned by the Vport.ConnectedTo property
 for vport in ixnetwork.Vport.find():
-	port = sessions.GetObjectFromHref(vport.ConnectedTo)
+	port = session_assistant.Session.GetObjectFromHref(vport.ConnectedTo)
 	if port is not None:
 		port.ClearOwnership()
 
