@@ -67,7 +67,7 @@ class ActionsProfile(Base):
         """
         Returns
         -------
-        - str: Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offers more context
+        - str: Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
         """
         return self._get_attribute(self._SDM_ATT_MAP['DescriptiveName'])
 
@@ -103,7 +103,7 @@ class ActionsProfile(Base):
 
         addFromTemplate(Arg2=href)
         --------------------------
-        - Arg2 (str(None | /api/v1/sessions/1/ixnetwork//.../*)): 
+        - Arg2 (str(None | /api/v1/sessions/30/ixnetwork//.../*)): 
 
         Raises
         ------
