@@ -217,7 +217,7 @@ class BgpMVpnReceiverSitesIpv6(Base):
         """
         Returns
         -------
-        - str: Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offers more context
+        - str: Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
         """
         return self._get_attribute(self._SDM_ATT_MAP['DescriptiveName'])
 
@@ -474,7 +474,7 @@ class BgpMVpnReceiverSitesIpv6(Base):
         Args
         ----
         - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
-        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offers more context
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
         - IncludeBierPtainLeafAd (bool): Include Bier PTA in Leaf A-D
         - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
         - WildCardLeafAdForBierPta (bool): Wildcard Leaf A-D For Bier PTA
@@ -566,7 +566,7 @@ class BgpMVpnReceiverSitesIpv6(Base):
     def Start(self, *args, **kwargs):
         """Executes the start operation on the server.
 
-        Start CPF control plane (equals to promote to negotiated state).
+        Start selected protocols.
 
         The IxNetwork model allows for multiple method Signatures with the same name while python does not.
 
@@ -591,7 +591,7 @@ class BgpMVpnReceiverSitesIpv6(Base):
     def Stop(self, *args, **kwargs):
         """Executes the stop operation on the server.
 
-        Stop CPF control plane (equals to demote to PreValidated-DoDDone state).
+        Stop selected protocols.
 
         The IxNetwork model allows for multiple method Signatures with the same name while python does not.
 
